@@ -533,7 +533,7 @@ namespace Breeze
     void ShadowHelper::uninstallWaylandShadows( QWidget* widget ) const
     {
         #if BREEZE_HAVE_KWAYLAND
-        if( widget->windowHandle()->parent() ) return;
+        if( widget->windowHandle() && widget->windowHandle()->parent() ) return;
         if( !_shadowManager ) return;
 
         using namespace KWayland::Client;
